@@ -1,4 +1,5 @@
-from .widget import Widget, DOMWidget, CallbackDispatcher, register, widget_serialization
+from .widget import Widget, CallbackDispatcher, register, widget_serialization, handle_version_comm_opened
+from .domwidget import DOMWidget
 
 from .trait_types import Color, EventfulDict, EventfulList
 
@@ -8,10 +9,12 @@ from .widget_box import Box, FlexBox, Proxy, PlaceProxy, HBox, VBox
 from .widget_float import FloatText, BoundedFloatText, FloatSlider, FloatProgress, FloatRangeSlider
 from .widget_image import Image
 from .widget_int import IntText, BoundedIntText, IntSlider, IntProgress, IntRangeSlider
+from .widget_color import ColorPicker
 from .widget_output import Output
-from .widget_selection import RadioButtons, ToggleButtons, Dropdown, Select, SelectMultiple
+from .widget_selection import RadioButtons, ToggleButtons, Dropdown, Select, SelectionSlider, SelectMultiple
 from .widget_selectioncontainer import Tab, Accordion
-from .widget_string import HTML, Latex, Text, Textarea
-from .widget_controller import Controller 
+from .widget_string import HTML, Label, Latex, Text, Textarea
+from .widget_controller import Controller
 from .interaction import interact, interactive, fixed, interact_manual
 from .widget_link import jslink, jsdlink
+from .widget_layout import Layout
